#ifndef BIG_INTEGER_H
#define BIG_INTEGER_H

#include <istream>
#include <ostream>
#include <string>
#include <cmath>
#include <complex>
#include <vector>

class BigInteger
{
public:
	BigInteger();
	BigInteger(std::string number);
	BigInteger(std::string number, size_t cap);
	BigInteger(const BigInteger &number);
	~BigInteger();
	size_t Length() const;
	BigInteger operator*(const BigInteger &number) const;
	BigInteger &operator=(const BigInteger &number);
	bool operator==(const BigInteger &number) const;
	friend std::istream &operator>>(std::istream &in, BigInteger &number);
	friend std::ostream &operator<<(std::ostream &out, const BigInteger &number);

private:
	char sign;
	size_t len; // length
	size_t cap; // capacity
	char *digits;

	void resize(size_t size);
	std::vector<std::complex<double>> fft(const std::vector<std::complex<double>> &factors) const;
	std::vector<std::complex<double>> ifft(const std::vector<std::complex<double>> &factors) const;
	std::vector<std::complex<double>> fft_algorithm(const std::vector<std::complex<double>> &factors, bool inverse = false) const;
};

#endif